Cheshire3 Objects: RecordStore

|  | ## Cheshire3 Objects: Record Store

Description

A persistent storage mechanism for Records. It allows such operations as create, update, fetch and delete. It also allows fast retrieval of the record's size for use with computing relevance ranking.

Implementations

- recordStore.FileSystemRecordStore
  Stores records in the file system
- recordStore.BdbRecordStore
  The recommended implementation, it stores records in BerkeleyDB stores.
- recordStore.ParsingRecordStore
  This store references unparsed data, parses it on demand and returns it. Useful for large databases of small objects

API

Function | Parameters | Returns | Description
--- | --- | --- | ---
__init__ | config, parent |  |
create_record | session, record | id | Create a new record with a new identifier
delete_record | session, id |  | Delete the record with the given identifier
fetch_record | session, id | Record | Return the record with the given identifier
fetch_recordMetadata | session, id, type | String | Return metadata of the given type (e.g. wordCount, byteCount) for the record with the given identifier
store_record | session, record | record | Store an existing record
close | session |  | Ensure data is commited to disk